@@ -19,6 +19,7 @@ import os
 import re
 import sys
 from contextlib import nullcontext
+from dataclasses import dataclass
 from pathlib import Path
 from shutil import which
 from textwrap import dedent, indent, shorten
@@ -37,7 +38,7 @@ from click_extra.platform import CURRENT_OS_ID, is_linux
 from click_extra.run import INDENT, format_cli, run_cmd
 
 from . import logger
-from .version import TokenizedString, parse_version
+from .version import parse_version
 
 
 class CLIError(Exception):
@@ -74,6 +75,26 @@ class CLIError(Exception):
         return f"<{self.__class__.__name__}({self.code}, {error_excerpt!r})>"
 
 
+@dataclass
+class Package:
+    """Lightweight representation of a package and its metadata."""
+
+    id: str
+    name: str = None
+    description: str = None
+    installed_version: str = None
+    latest_version: str = None
+
+    def __post_init__(self):
+        # XXX A name is not required but the table rendering code is not capable
+        # of rendering None values yet.
+        if not self.name:
+            self.name = self.id
+        # Make sure version strings are parsed into proper objects.
+        self.installed_version = parse_version(self.installed_version)
+        self.latest_version = parse_version(self.latest_version)
+
+
 class PackageManager:
 
     """Base class from which all package manager definitions inherits."""
@@ -98,6 +119,9 @@ class PackageManager:
         """
         return cls.__name__
 
+    homepage_url = None
+    """Home page of the project, only used in documentation for reference."""
+
     platforms = frozenset()
     """List of platforms supported by the manager."""
 
@@ -179,7 +203,8 @@ class PackageManager:
     """Do not actually perform any action, just simulate CLI calls."""
 
     def __init__(self):
-        # Log of all encountered CLI errors.
+        """Initialize a ``self.cli_errors`` list to accumulate all CLI errors
+        encountered by the package mananger."""
         self.cli_errors = []
 
     @classproperty
@@ -604,6 +629,14 @@ class PackageManager:
         """
         raise NotImplementedError
 
+    @classmethod
+    def query_parts(cls, query):
+        """Returns a set of all contiguous alphanumeric string segments.
+
+        Contrary to :py:class:`meta_package_manager.version.TokenizedString`, do no splits on colated number/alphabetic junctions.
+        """
+        return {p for p in re.split(r"\W+", query) if p}
+
     def search(self, query, extended, exact):
         """Search packages available for install.
 
@@ -644,35 +677,49 @@ class PackageManager:
         """Returns search results with extra manual refiltering to refine gross
         matchings.
 
-        Some package managers returns unbounded results, and don't support finer
+        Some package managers returns unbounded results, and/or don't support fine
         search criterions. In which case we use this method to manually refilters
-        :py:meth:`meta_package_manager.base.PackageManager.search`
-        results to either exclude non-extended
-        or non-exact matches.
+        :py:meth:`meta_package_manager.base.PackageManager.search` results to either
+        exclude non-extended or non-exact matches.
 
-        Returns a generator producing the same data as the :py:meth:`meta_package_manager.base.PackageManager.search` method above.
+        Returns a generator producing the same data as the
+        :py:meth:`meta_package_manager.base.PackageManager.search` method above.
 
-        There is no need to have this method implemented by package manager definitions. Just implement the core
-        :py:meth:`meta_package_manager.base.PackageManager.search` method and produce results as precise as possible.
+        .. tip::
+
+            If you are implementing a package manager definition, do not waste time to
+            filter CLI results. Let this method do this job.
+
+            Instead, just implement the core
+            :py:meth:`meta_package_manager.base.PackageManager.search` method above and
+            try to produce results as precise as possible using the native filtering
+            capabilities of the package manager CLI.
         """
         for match in self.search(query, extended, exact):
+            # Look by default into package ID and name.
+            search_content = {match.id, match.name}
 
-            package_id = match["id"]
-            package_name = match["name"]
-            description = match["description"]
-            version = match["latest_version"]
-
-            # Exclude packages not featuring the search query in their ID or name.
-            if not extended:
-                query_parts = set(map(str, TokenizedString(query)))
-                pkg_parts = set(map(str, TokenizedString(package_id)))
-                if not query_parts.issubset(pkg_parts):
-                    continue
-
-            # Filters out fuzzy matches, only keep stricly matching packages.
-            if exact and query not in (package_id, package_name):
+            # Rejects fuzzy results: only keep packages stricly matching on ID or name.
+            if exact and query not in search_content:
                 continue
 
+            # Add description to the list of content to look into.
+            if extended:
+                search_content.add(match.description)
+
+            # Normalize searched content.
+            search_content = "".join({s.lower() for s in search_content if s})
+
+            # Exclude packages not matching any part of the query.
+            confirmed_match = False
+            for part in {p.lower() for p in self.query_parts(query)}:
+                if part in search_content:
+                    confirmed_match = True
+                    break
+            if not confirmed_match:
+                continue
+
+            # Report the package as matching.
             yield match
 
     def install(self, package_id):
