@@ -15,12 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+import dataclasses
 import logging
 import sys
 from collections import namedtuple
 from datetime import datetime
 from functools import partial
 from io import TextIOWrapper
+from operator import attrgetter
 from pathlib import Path
 from unittest.mock import patch
 
@@ -49,17 +51,17 @@ else:
 from cloup import Section
 
 from . import __version__, bar_plugin, logger
-from .base import CLIError
+from .base import CLIError, PackageManager
 from .output import (
     SORTABLE_FIELDS,
     BarPluginRenderer,
     TabularOutputFormatter,
+    colored_diff,
     print_json,
     print_stats,
     print_table,
 )
 from .pool import pool
-from .version import TokenizedString
 
 # Subcommand sections.
 EXPLORE = Section("Explore subcommands")
@@ -371,7 +373,7 @@ def installed(ctx):
     for manager in ctx.obj.selected_managers:
 
         try:
-            packages = tuple(manager.installed.values())
+            packages = tuple(map(dataclasses.asdict, manager.installed))
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement installed operation.")
             continue
@@ -439,7 +441,7 @@ def outdated(ctx, plugin_output):
     for manager in ctx.obj.selected_managers:
 
         try:
-            packages = tuple(map(dict, manager.outdated.values()))
+            packages = tuple(map(dataclasses.asdict, manager.outdated))
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement outdated operation.")
             continue
@@ -494,16 +496,20 @@ def outdated(ctx, plugin_output):
     # Human-friendly content rendering.
     table = []
     for manager_id, outdated_pkg in outdated_data.items():
-        table += [
-            (
-                info["name"],
-                info["id"],
-                manager_id,
+        for info in outdated_pkg["packages"]:
+            installed_version, latest_version = colored_diff(
                 info["installed_version"] if info["installed_version"] else "?",
                 info["latest_version"],
             )
-            for info in outdated_pkg["packages"]
-        ]
+            table.append(
+                (
+                    info["name"],
+                    info["id"],
+                    manager_id,
+                    installed_version,
+                    latest_version,
+                )
+            )
 
     # Sort and print table.
     print_table(
@@ -555,7 +561,12 @@ def search(ctx, extended, exact, query):
     for manager in ctx.obj.selected_managers:
 
         try:
-            results = tuple(manager.refiltered_search(query, extended, exact))
+            results = tuple(
+                map(
+                    dataclasses.asdict,
+                    manager.refiltered_search(query, extended, exact),
+                )
+            )
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement search operation.")
             continue
@@ -577,7 +588,7 @@ def search(ctx, extended, exact, query):
         return
 
     # Prepare highlighting helpers.
-    query_parts = {query}.union(map(str, TokenizedString(query)))
+    query_parts = {query}.union(PackageManager.query_parts(query))
     highlight_query = cached(LRI(max_size=1000))(
         partial(
             highlight,
@@ -702,7 +713,7 @@ def remove(ctx, package_id):
         # Is the package installed with this manager?
         installed = set()
         try:
-            installed = {package["id"] for package in manager.installed.values()}
+            installed = map(attrgetter("id"), manager.installed)
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement installed operation.")
             logger.info(
@@ -782,8 +793,9 @@ def backup(ctx, toml_output):
             return
 
     # Leave some metadata as comment.
-    doc = f"# Generated by mpm v{__version__}.\n"
-    doc += f"# Timestamp: {datetime.now().isoformat()}.\n"
+    write = toml_output.write
+    write(f"# Generated by mpm v{__version__}.\n")
+    write(f"# Timestamp: {datetime.now().isoformat()}.\n")
 
     installed_data = {}
 
@@ -792,7 +804,7 @@ def backup(ctx, toml_output):
         logger.info(f"Dumping packages from {manager.id}...")
 
         try:
-            packages = manager.installed.values()
+            packages = tuple(map(dataclasses.asdict, manager.installed))
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement installed operation.")
             continue
@@ -803,14 +815,19 @@ def backup(ctx, toml_output):
             "packages": packages,
         }
 
-        pkg_data = dict(
-            sorted((p["id"], str(p["installed_version"])) for p in packages)
-        )
-
-        if pkg_data:
-            doc += "\n" + tomli_w.dumps({manager.id: pkg_data})
-
-    toml_output.write(doc)
+        if packages:
+            write("\n")
+            write(
+                tomli_w.dumps(
+                    {
+                        manager.id: dict(
+                            sorted(
+                                (p["id"], str(p["installed_version"])) for p in packages
+                            )
+                        )
+                    }
+                )
+            )
 
     if ctx.obj.stats:
         print_stats(installed_data)
