@@ -17,11 +17,11 @@
 
 import json
 import re
+from operator import methodcaller
 
 from click_extra.platform import LINUX, MACOS
 
-from .. import logger
-from ..base import PackageManager
+from ..base import Package, PackageManager
 from ..version import parse_version
 
 
@@ -104,23 +104,24 @@ class Homebrew(PackageManager):
             /reporting_bugs/uninstall_wrongly_reports_cask_as_not_installed.md
             and https://github.com/kdeldycke/meta-package-manager/issues/17 .
         """
-        installed = {}
-
         output = self.run_cli("list", "--versions")
 
-        regexp = re.compile(r"(\S+)( \(!\))? (.+)")
-        for pkg_info in output.splitlines():
-            match = regexp.match(pkg_info)
-            if match:
-                package_id, removed, versions = match.groups()
-                installed[package_id] = {
-                    "id": package_id,
-                    "name": package_id,
-                    # Keep highest version found.
-                    "installed_version": max(map(parse_version, versions.split())),
-                }
+        regexp = re.compile(
+            r"""
+            (?P<package_id>\S+)     # Any non-empty characters.
+            (?P<removed> \(!\))?    # Package removed flag.
+            \                       # A space.
+            (?P<versions>.+)        # Versions.
+            """,
+            re.VERBOSE,
+        )
 
-        return installed
+        for package_id, removed, versions in map(
+            methodcaller("groups"), regexp.finditer(output)
+        ):
+            # Keep highest version found.
+            version = max(map(parse_version, versions.split()))
+            yield Package(id=package_id, installed_version=version)
 
     @property
     def outdated(self):
@@ -206,8 +207,6 @@ class Homebrew(PackageManager):
               ]
             }
         """
-        outdated = {}
-
         # Build up the list of CLI options.
         options = ["--json=v2"]
         # Includes auto-update packages or not.
@@ -220,7 +219,7 @@ class Homebrew(PackageManager):
         if output:
             package_list = json.loads(output)
             for pkg_info in package_list["formulae"] + package_list["casks"]:
-                package_id = pkg_info["name"]
+
                 version = pkg_info["installed_versions"]
                 if not isinstance(version, str):
                     version = max(map(parse_version, version))
@@ -230,14 +229,11 @@ class Homebrew(PackageManager):
                 if version == latest_version:
                     continue
 
-                outdated[package_id] = {
-                    "id": package_id,
-                    "name": package_id,
-                    "installed_version": parse_version(version),
-                    "latest_version": parse_version(latest_version),
-                }
-
-        return outdated
+                yield Package(
+                    id=pkg_info["name"],
+                    installed_version=version,
+                    latest_version=latest_version,
+                )
 
     def search(self, query, extended, exact):
         """Fetch matching packages.
@@ -287,18 +283,58 @@ class Homebrew(PackageManager):
         .. code-block:: shell-session
 
             ► brew search "/^sed$/" --formulae
-            No formula or cask found for "/^sed$/".
-            Closed pull requests:
-            Merge ba7a794 (https://github.com/Homebrew/linuxbrew-core/pull/198)
-            R: disable Tcl (https://github.com/Homebrew/homebrew-core/pull/521)
-            (...)
+            Error: No formula or cask found for "/^sed$/".
 
-        More doc at: https://docs.brew.sh/Manpage#search-texttext
+        .. code-block:: shell-session
+
+            ► brew search tetris --formulae --desc
+            ==> Formulae
+            bastet: Bastard Tetris
+            netris: Networked variant of tetris
+            vitetris: Terminal-based Tetris clone
+            yetris: Customizable Tetris for the terminal
+
+        .. code-block:: shell-session
+
+            ► brew search tetris --cask --desc
+            ==> Casks
+            not-tetris: (Not Tetris) [no description]
+            tetrio: (TETR.IO) Free-to-play Tetris clone
+
+        More doc at: https://docs.brew.sh/Manpage#search--s-options-textregex-
         """
-        if extended:
-            logger.warning(f"{self.id} does not implement extended search operation.")
+        # Keep track of package IDs already matched by the first extended search pass.
+        matched_ids = set()
 
-        # Use regexp for exact match.
+        # Additional search on description only.
+        if extended:
+            output = self.run_cli("search", query, "--desc")
+
+            regexp = re.compile(
+                r"""
+                (?:==>\s\S+\s)?           # Ignore section starting with '==>'.
+                (?P<package_id>\S+)       # Any non-empty characters.
+                :                         # Semi-colon.
+                (                         # Optional group start (ignored below with "_" variable).
+                    \s+                   # Blank characters.
+                    \(                    # Opening parenthesis.
+                    (?P<package_name>.+)  # Any string.
+                    \)                    # Closing parenthesis.
+                )?                        # Optional group end.
+                \s+                       # Blank characters.
+                (?P<description>.+)       # Any string.
+                """,
+                re.VERBOSE,
+            )
+
+            for package_id, _, package_name, description in regexp.findall(output):
+                matched_ids.add(package_id)
+                pkg = Package(id=package_id, name=package_name)
+                if description != "[no description]":
+                    pkg.description = description
+                yield pkg
+
+        # Use regexp if exact match is requested.
         if exact:
             query = f"/^{query}$/"
 
@@ -313,12 +349,9 @@ class Homebrew(PackageManager):
         )
 
         for package_id in regexp.findall(output):
-            yield {
-                "id": package_id,
-                "name": package_id,
-                "description": None,
-                "latest_version": None,
-            }
+            # Deduplicate search results.
+            if package_id not in matched_ids:
+                yield Package(id=package_id)
 
     def install(self, package_id):
         """Install one package.
@@ -477,6 +510,8 @@ class Brew(Homebrew):
 
     name = "Homebrew Formulae"
 
+    homepage_url = "https://brew.sh"
+
     cli_names = ("brew",)
 
     post_args = ("--formula",)
@@ -486,6 +521,8 @@ class Cask(Homebrew):
 
     name = "Homebrew Cask"
 
+    homepage_url = "https://caskroom.github.io"
+
     # Casks are only available on macOS, not Linux.
     platforms = frozenset({MACOS})
 
