@@ -16,24 +16,30 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import json
-from operator import itemgetter
 
 from boltons.iterutils import remap
 from click_extra.platform import LINUX, MACOS, WINDOWS
 
 from .. import logger
-from ..base import PackageManager
-from ..version import parse_version
+from ..base import Package, PackageManager
 
 
 class NPM(PackageManager):
 
     name = "Node's npm"
 
+    homepage_url = "https://www.npmjs.com"
+
     platforms = frozenset({LINUX, MACOS, WINDOWS})
 
     requirement = "4.0.0"
 
+    pre_args = (
+        "--global",
+        "--progress=false",
+        "--no-update-notifier",
+    )
+
     """
     .. code-block:: shell-session
 
@@ -48,7 +54,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm --global --progress=false --json --no-update-notifier outdated
+            ► npm --global --progress=false --no-update-notifier --json outdated
             {
               "error": {
                 "code": "ERR_OUT_OF_RANGE",
@@ -75,7 +81,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm --global --json list | jq
+            ► npm --global --progress=false --no-update-notifier --json list | jq
             {
               "dependencies": {
                 "npm": {
@@ -110,20 +116,16 @@ class NPM(PackageManager):
                     },
             (...)
         """
-        installed = {}
+        installed = []
 
-        output = self.run_cli("--global", "--json", "list")
+        output = self.run_cli("--json", "list")
 
         if output:
 
             def visit(path, key, value):
                 if key == "version":
                     package_id = path[-1]
-                    installed[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "installed_version": parse_version(value),
-                    }
+                    installed.append(Package(id=package_id, installed_version=value))
                 return True
 
             remap(json.loads(output), visit=visit)
@@ -136,7 +138,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm --global --progress=false --json --no-update-notifier outdated
+            ► npm --global --progress=false --no-update-notifier --json outdated
             {
               "my-linked-package": {
                 "current": "0.0.0-development",
@@ -152,28 +154,17 @@ class NPM(PackageManager):
               }
             }
         """
-        outdated = {}
-
-        output = self.run_cli(
-            "--global",
-            "--progress=false",
-            "--json",
-            "--no-update-notifier",
-            "outdated",
-        )
+        output = self.run_cli("--json", "outdated")
 
         if output:
             for package_id, values in json.loads(output).items():
                 if values["wanted"] == "linked":
                     continue
-                outdated[package_id] = {
-                    "id": f"{package_id}@{values['latest']}",
-                    "name": package_id,
-                    "installed_version": parse_version(values["current"]),
-                    "latest_version": parse_version(values["latest"]),
-                }
-
-        return outdated
+                yield Package(
+                    id=f"{package_id}@{values['latest']}",
+                    installed_version=values["current"],
+                    latest_version=values["latest"],
+                )
 
     def search(self, query, extended, exact):
         """Fetch matching packages.
@@ -185,7 +176,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm search --json python | jq
+            ► npm --global --progress=false --no-update-notifier search --json python | jq
             [
               {
                 "name": "python",
@@ -253,7 +244,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm search --json --no-description python | jq
+            ► npm --global --progress=false --no-update-notifier search --json --no-description python | jq
         """
         if exact:
             logger.warning(f"{self.id} does not implement exact search operation.")
@@ -265,15 +256,12 @@ class NPM(PackageManager):
         output = self.run_cli("search", "--json", search_args, query)
 
         if output:
-            for package_id, version, description in map(
-                itemgetter("name", "version", "description"), json.loads(output)
-            ):
-                yield {
-                    "id": package_id,
-                    "name": package_id,
-                    "description": description,
-                    "latest_version": parse_version(version),
-                }
+            for pkg in json.loads(output):
+                yield Package(
+                    id=pkg.get("name"),
+                    description=pkg.get("description"),
+                    latest_version=pkg.get("version"),
+                )
 
     def install(self, package_id):
         """Install one package.
@@ -282,13 +270,7 @@ class NPM(PackageManager):
 
             ► npm --global --progress=false --no-update-notifier install raven
         """
-        return self.run_cli(
-            "--global",
-            "--progress=false",
-            "--no-update-notifier",
-            "install",
-            package_id,
-        )
+        return self.run_cli("install", package_id)
 
     def upgrade_cli(self, package_id=None, version=None):
         """Generates the CLI to upgrade all packages (default) or only the one provided
@@ -309,6 +291,4 @@ class NPM(PackageManager):
                 f"{package_id}@{version}" if version else package_id,
             )
 
-        return self.build_cli(
-            "--global", "--progress=false", "--no-update-notifier", *cmd_args
-        )
+        return self.build_cli(*cmd_args)
