@@ -20,13 +20,14 @@ import re
 from click_extra.platform import LINUX
 
 from .. import logger
-from ..base import PackageManager
-from ..version import parse_version
+from ..base import Package, PackageManager
 
 
 class Pacman(PackageManager):
     """See command equivalences at: https://wiki.archlinux.org/title/Pacman/Rosetta."""
 
+    homepage_url = "https://wiki.archlinux.org/title/pacman"
+
     platforms = frozenset({LINUX})
 
     requirement = "5.0.0"
@@ -64,8 +65,6 @@ class Pacman(PackageManager):
             acpi 1.7-3
             acpid 2.0.33-1
         """
-        installed = {}
-
         output = self.run_cli("--query")
 
         regexp = re.compile(r"(\S+) (\S+)")
@@ -73,13 +72,7 @@ class Pacman(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, installed_version = match.groups()
-                installed[package_id] = {
-                    "id": package_id,
-                    "name": package_id,
-                    "installed_version": parse_version(installed_version),
-                }
-
-        return installed
+                yield Package(id=package_id, installed_version=installed_version)
 
     @property
     def outdated(self):
@@ -91,8 +84,6 @@ class Pacman(PackageManager):
             linux 4.19.1.arch1-1 -> 4.19.2.arch1-1
             linux-headers 4.19.1.arch1-1 -> 4.19.2.arch1-1
         """
-        outdated = {}
-
         output = self.run_cli("--query", "--upgrades")
 
         regexp = re.compile(r"(\S+) (\S+) -> (\S+)")
@@ -100,13 +91,11 @@ class Pacman(PackageManager):
             match = regexp.match(package)
             if match:
                 package_id, installed_version, latest_version = match.groups()
-                outdated[package_id] = {
-                    "id": package_id,
-                    "name": package_id,
-                    "latest_version": parse_version(latest_version),
-                    "installed_version": parse_version(installed_version),
-                }
-        return outdated
+                yield Package(
+                    id=package_id,
+                    latest_version=latest_version,
+                    installed_version=installed_version,
+                )
 
     def search(self, query, extended, exact):
         """Fetch matching packages.
@@ -146,48 +135,46 @@ class Pacman(PackageManager):
         )
 
         for package_id, version, description in regexp.findall(output):
-            yield {
-                "id": package_id,
-                "name": package_id,
-                "description": description,
-                "latest_version": parse_version(version),
-            }
+            yield Package(
+                id=package_id,
+                description=description,
+                latest_version=version,
+            )
 
     def install(self, package_id):
         """Install one package.
 
         .. code-block:: shell-session
 
-            ► pacman --noconfirm --sync firefox
+            ► sudo pacman --noconfirm --sync firefox
         """
-        return self.run_cli("--sync", package_id)
+        return self.run_cli("--sync", package_id, sudo=True)
 
     def upgrade_cli(self, package_id=None):
         """Generates the CLI to upgrade the package provided as parameter.
 
         .. code-block:: shell-session
 
-            ► pacman --noconfirm --sync --refresh --sysupgrade
+            ► sudo pacman --noconfirm --sync --refresh --sysupgrade
 
         .. code-block:: shell-session
 
-            ► pacman --noconfirm --sync firefox
+            ► sudo pacman --noconfirm --sync firefox
         """
         params = ("--refresh", "--sysupgrade")
         if package_id:
             params = (package_id,)
 
-        return self.build_cli("--sync", *params)
+        return self.build_cli("--sync", *params, sudo=True)
 
     def remove(self, package_id):
         """Removes a package.
 
         .. code-block:: shell-session
 
-            ► pacman --noconfirm --remove firefox
+            ► sudo pacman --noconfirm --remove firefox
         """
-
-        self.run_cli("--remove", package_id)
+        self.run_cli("--remove", package_id, sudo=True)
 
     def sync(self):
         """Sync package metadata.
@@ -203,18 +190,38 @@ class Pacman(PackageManager):
 
         .. code-block:: shell-session
 
-            ► pacman --noconfirm --sync --clean --clean
+            ► sudo pacman --noconfirm --sync --clean --clean
         """
-        self.run_cli("--sync", "--clean", "--clean")
+        self.run_cli("--sync", "--clean", "--clean", sudo=True)
+
+
+class Paru(Pacman):
+    """``paru`` wraps ``pacman`` and shadows its options."""
+
+    homepage_url = "https://github.com/Morganamilo/paru"
+
+    # v1.9.3 is the first version implementing the --sysupgrade option.
+    requirement = "1.9.3"
+
+    version_regex = r"paru\s+v(?P<version>\S+)"
+    r"""Search version right after the ``paru`` string.
+
+    .. code-block:: shell-session
+
+        ► paru --version
+        paru v1.10.0 - libalpm v13.0.1
+    """
 
 
 class Yay(Pacman):
-    """yay has the commands equivalent to pacman."""
+    """``yay`` wraps ``pacman`` and shadows its options."""
+
+    homepage_url = "https://github.com/Jguer/yay"
 
     requirement = "11.0.0"
 
-    version_regex = r".*yay\s+v(?P<version>\S+)"
-    r"""Search version right after the ``yay `` string.
+    version_regex = r"yay\s+v(?P<version>\S+)"
+    r"""Search version right after the ``yay`` string.
 
     .. code-block:: shell-session
 
