@@ -42,7 +42,6 @@ from click_extra import echo, get_current_context, style
 from click_extra.tabulate import TabularOutputFormatter
 from tabulate import DataRow, TableFormat, tabulate
 
-from . import __version__
 from .bar_plugin import MPMPlugin
 from .version import TokenizedString
 
@@ -56,6 +55,42 @@ SORTABLE_FIELDS = {
 """List of fields IDs allowed to be sorted."""
 
 
+def colored_diff(a, b, style_common=None, style_a=None, style_b=None):
+    """Highlight the most common left part between ``a`` and ``b`` strings and their
+    trailing differences.
+
+    Always returns 2 strings.
+    """
+    # Set defaults stling methods.
+    style_common = partial(style, fg="bright_black")
+    style_a = partial(style, fg="red")
+    style_b = partial(style, fg="green")
+
+    if isinstance(a, TokenizedString):
+        a = str(a)
+    if isinstance(b, TokenizedString):
+        b = str(b)
+
+    common_size = 0
+    if a and b:
+        while (min(len(a), len(b)) - 1) >= common_size and a[common_size] == b[
+            common_size
+        ]:
+            common_size += 1
+
+    # Styling of common and different parts.
+    colored_a = ""
+    colored_b = ""
+    if common_size:
+        colored_a = colored_b = style_common(a[:common_size])
+    if a:
+        colored_a += style_a(a[common_size:])
+    if b:
+        colored_b += style_b(b[common_size:])
+
+    return colored_a, colored_b
+
+
 def not_implemented_json_handler(data, headers, **kwargs):
     """Dummy `TabularOutputFormatter <https://cli-helpers.readthedocs.io/en/latest/api.h
     tml#cli_helpers.tabular_output.TabularOutputFormatter>`_ renderer.
@@ -282,6 +317,8 @@ class BarPluginRenderer(MPMPlugin):
         """Renders a table data with pre-configured alignment centered around the third
         column.
 
+        Returns a list of strings, one item per line.
+
         .. code-block:: pycon
 
             >>> table_data = [
@@ -294,12 +331,14 @@ class BarPluginRenderer(MPMPlugin):
             blockblock 5.33,VHSDGataYCcV8xqv5TSZA → 5.39
             sed                                 2 → 2021.0328
         """
+        if not table_data:
+            return []
         return tabulate(
             table_data,
             tablefmt=BarPluginRenderer.plain_table_format,
             colalign=("left", "right", "center", "left"),
             disable_numparse=True,
-        )
+        ).splitlines()
 
     def _render(self, outdated_data):
         """Main method implementing the final structured rendering in *Bar plugin
@@ -335,7 +374,7 @@ class BarPluginRenderer(MPMPlugin):
             # Table-like rendering
             if self.table_rendering:
                 header = f"{manager['id']} - {package_count} {package_label}"
-                formatted_lines = self.render_table([p[0] for p in table]).splitlines()
+                formatted_lines = self.render_table([p[0] for p in table])
 
             # Variable-width / non-table / non-monospaced rendering.
             else:
