@@ -25,9 +25,10 @@ from types import MethodType
 
 import pytest
 from boltons.iterutils import unique
+from boltons.urlutils import URL
 from click_extra.platform import OS_DEFINITIONS
 
-from ..base import PackageManager
+from ..base import Package, PackageManager
 from ..cli import XKCD_MANAGER_ORDER
 from ..pool import pool
 from ..version import TokenizedString
@@ -69,6 +70,15 @@ def test_unique_names():
     assert len({m.name for m in pool.values()}) == len(pool.all_manager_ids)
 
 
+@all_managers
+def test_homepage_url(manager):
+    assert manager.homepage_url
+    assert isinstance(manager.homepage_url, str)
+    location = URL(manager.homepage_url)
+    assert location
+    assert location.scheme.lower() in ("http", "https")
+
+
 @all_managers
 def test_platforms(manager):
     """Check that definitions returns supported platforms as a frozenset."""
@@ -209,14 +219,11 @@ def test_installed_type(manager):
         except Exception as ex:
             assert isinstance(ex, NotImplementedError)
         else:
-            assert isinstance(result, dict)
-            for pkg in manager.installed.values():
-                assert isinstance(pkg, dict)
-                assert set(pkg) == {"id", "name", "installed_version"}
-                assert isinstance(pkg["id"], str)
-                assert isinstance(pkg["name"], str)
-                if pkg["installed_version"] is not None:
-                    assert isinstance(pkg["installed_version"], TokenizedString)
+            # XXX There is an exception in the way npm.installed is implemented as it use a recursive
+            # boltons.remap strategy to parse the tree-like JSON.
+            assert isinstance(result, (list, types.GeneratorType))
+            for pkg in result:
+                assert isinstance(pkg, Package)
 
 
 @all_managers
@@ -228,15 +235,22 @@ def test_outdated_type(manager):
         except Exception as ex:
             assert isinstance(ex, NotImplementedError)
         else:
-            assert isinstance(result, dict)
-            for pkg in manager.outdated.values():
-                assert isinstance(pkg, dict)
-                assert set(pkg) == {"id", "name", "installed_version", "latest_version"}
-                assert isinstance(pkg["id"], str)
-                assert isinstance(pkg["name"], str)
-                if pkg["installed_version"] is not None:
-                    assert isinstance(pkg["installed_version"], TokenizedString)
-                assert isinstance(pkg["latest_version"], TokenizedString)
+            assert isinstance(result, types.GeneratorType)
+            for pkg in result:
+                assert isinstance(pkg, Package)
+
+
+@pytest.mark.parametrize(
+    "query,query_parts",
+    (
+        ("cli-l-cli", {"cli", "l"}),
+        ("ab12--cd34", {"ab12", "cd34"}),
+        ("123/extra.34", {"123", "extra", "34"}),
+        ("AB ab", {"AB", "ab"}),
+    ),
+)
+def test_query_parts(query, query_parts):
+    assert PackageManager.query_parts(query) == query_parts
 
 
 @all_managers
@@ -252,14 +266,7 @@ def test_search_type(manager):
         else:
             assert isinstance(matches, types.GeneratorType)
             for pkg in matches:
-                assert isinstance(pkg, dict)
-                assert set(pkg) == {"id", "name", "description", "latest_version"}
-                assert isinstance(pkg["id"], str)
-                assert isinstance(pkg["name"], str)
-                if pkg["description"] is not None:
-                    assert isinstance(pkg["description"], str)
-                if pkg["latest_version"] is not None:
-                    assert isinstance(pkg["latest_version"], TokenizedString)
+                assert isinstance(pkg, Package)
 
 
 @all_managers
